@@ -1,48 +1,51 @@
 
-def train(data, used_model='autoreg', p=5, d=1, q=0, cov_type='nonrobust', method='cmle', ic='aic', trend='nc', solver='lbfgs', maxlag=13,
+
+def train(data, used_model='autoreg', p=5, d=1, q=0, cov_type='nonrobust', method='cmle', trend='nc', solver='lbfgs', maxlag=13,
           # SARIMAX args
-          seasonal=(1, 1, 1, 24), enforce_invertibility=False, enforce_stationarity=False):
+          seasonal=(1, 1, 1, 24)  # , enforce_invertibility=False, enforce_stationarity=False
+          ):
     """Autoregressive model from statsmodels library. Only univariate data.
     Args:
         data (np.ndarray): Time series data.
-        predicts (int, optional): Number of predicted values. Defaults to 7.
-        plot (int, optional): Whether plot results. Defaults to 0.
-        predicted_column_index (int, optional): If multidimensional, define what column is predicted. Defaults to 0.
-        method (str, optional): Parameter of statsmodels fit function. Defaults to 'cmle'.
-        ic (str, optional): Parameter of statsmodels fit function. Defaults to 'aic'.
-        trend (str, optional): Parameter of statsmodels fit function. Defaults to 'nc'.
-        solver (str, optional):ort statsmodels.api as sm
-      File "/home/dan/.local/lib/pyt Parameter of statsmodels fit function. Defaults to 'lbfgs'.
+        used_model (str, optional): One of ['ar', 'arima', 'sarimax', 'autoreg'].
+        p (int) - Order of ARIMA model (1st - proportional). Check statsmodels docs for more.
+        d (int) - Order of ARIMA model.
+        q (int) - Order of ARIMA model.
+        cov_type, method, trend, solver, maxlag, seasonal: Parameters of model call or fit function of particular model.
+            Check statsmodels docs for more.
     Returns:
-        np.ndarray: Predictions of input time series.
+        statsmodels.model: Trained model.
     """
 
     import statsmodels.tsa.api as sm
-    import statsmodels.tsa.ar_model as ar_model
+    from statsmodels.tsa.statespace.sarimax import SARIMAX
+    from statsmodels.tsa.arima.model import ARIMA
+    from statsmodels.tsa import ar_model
+
+    used_model = used_model.lower()
 
     if used_model == 'ar':
         model = sm.AR(data)
-
-    elif used_model == 'arma':
-        order = (p, q)
-        model = sm.ARMA(data, order=order)
+        fitted_model = model.fit(method=method, trend=trend, solver=solver, disp=0)
 
     elif used_model == 'arima':
         order = (p, d, q)
-        model = sm.ARIMA(data, order=order)
+        model = ARIMA(data, order=order)
+        fitted_model = model.fit()
 
     elif used_model == 'sarimax':
         order = (p, d, q)
-        model = sm.SARIMAX(data, order=order, seasonal_order=seasonal)
-
-    if used_model in ('ar', 'arma', 'arima', 'sarimax'):
-        fitted_model = model.fit(method=method, ic=ic, trend=trend, solver=solver, disp=0)
+        model = SARIMAX(data, order=order, seasonal_order=seasonal)
+        fitted_model = model.fit(method=method, trend=trend, solver=solver, disp=0)
 
     elif used_model == 'autoreg':
         auto = ar_model.ar_select_order(data, maxlag=maxlag)
         model = ar_model.AutoReg(data, lags=auto.ar_lags, trend=auto.trend, seasonal=auto.seasonal, period=auto.period)
         fitted_model = model.fit(cov_type=cov_type)
 
+    else:
+        raise ValueError(f"Used model has to be one of ['ar', 'arima', 'sarimax', 'autoreg']. You configured: {used_model}")
+
     fitted_model.my_name = used_model
     fitted_model.data_len = len(data)
 
